library test.decoding;

import 'package:test/test.dart';
import 'package:jaguar_jwt/jaguar_jwt.dart';

final key = 'secret';

main() {
  group('Decoding', () {
    test('Nopayload', () {
      final String token =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhdWQiOlsiYWRtaW4iLCJzdHVkZW50cyJdLCJleHAiOjg2NDAwLCJpYXQiOiIyMDE2LTEyLTE1VDIzOjAwOjAwLjAwMFoiLCJpc3MiOiJ0ZWphIiwic3ViIjoiMTIzNDU2Nzg5MCJ9.Vni4th0LB6skPofO8r0T9R-qvptF-qEgRMbWvJdOzJ8=';

      final JwtClaim claimSet = verifyJwtHS256Signature(token, key);

      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.subject, "1234567890");
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, isEmpty);
      expect(claimSet.issuedAt,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000, isUtc: true));
      expect(
          claimSet.expiry,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000, isUtc: true)
              .add(new Duration(days: 1)));
    });

    test('With payload', () {
      String token =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhdWQiOlsiYWRtaW4iLCJzdHVkZW50cyJdLCJleHAiOjg2NDAwLCJpYXQiOiIyMDE2LTEyLTE1VDIzOjAwOjAwLjAwMFoiLCJpc3MiOiJ0ZWphIiwicGxkIjp7ImsiOiJ2In0sInN1YiI6IjEyMzQ1Njc4OTAifQ==.j0BpvzJdpy6mR6-b21eiPAnDCg84goe_oUsMrm9WRWU=';
      final JwtClaim claimSet = verifyJwtHS256Signature(token, key);
      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, equals({"k": "v"}));
      expect(claimSet.subject, "1234567890");
      expect(claimSet.issuedAt,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000, isUtc: true));
      expect(
          claimSet.expiry,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000, isUtc: true)
              .add(new Duration(days: 1)));
    });
  });
}
